@@ -11,6 +11,7 @@ from proxygen_cli.cli import (
     command_instance,
     command_spec,
     command_secret,
+    command_docker,
 )
 
 
@@ -24,6 +25,7 @@ main.add_command(command_credentials.credentials)
 main.add_command(command_instance.instance)
 main.add_command(command_spec.spec_cmd, name="spec")
 main.add_command(command_secret.secret)
+main.add_command(command_docker.docker)
 
 
 @main.command()
@@ -37,17 +39,5 @@ def status():
     )
 
 
-@main.command()
-@click.option(
-    "--api", default=SETTINGS.api, help="Override the default API", show_default=True
-)
-def docker_get_login(api):
-    """
-    Generate docker login command for AWS ECR repo with credentials from proxygen.
-    """
-    resp = proxygen_api.get_docker_login(api)
-    click.echo(f"docker login -u {resp['user']} --password {resp['password']} {resp['registry']}")
-
-
 if __name__ == "__main__":
     main()
